---
Date: '{{ today }}'
Release: '{{ release }}'
---

(api-index)=

# The PyZMQ API

```{toctree}
zmq
zmq.devices
zmq.decorators
zmq.green
zmq.eventloop.ioloop
zmq.eventloop.future
zmq.asyncio
zmq.eventloop.zmqstream
zmq.auth
zmq.auth.asyncio
zmq.auth.thread
zmq.auth.ioloop
zmq.log.handlers
zmq.ssh.tunnel
zmq.utils.jsonapi
zmq.utils.monitor
zmq.utils.z85
zmq.utils.win32
```
